/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef _GB2_UHMMER3_TESTS_H_
#define _GB2_UHMMER3_TESTS_H_

#include <QtCore/QList>
#include <U2Test/XMLTestFormat.h>

namespace U2 {

class UHMMER3Tests {
public:
    static QList<XMLTestFactory*> createTestFactories();
}; // UHMMER3Tests

} // GB2

#endif // _GB2_UHMMER3_TESTS_H_
